@@ -1,7 +1,7 @@
 package App::dateseq;
 
 our $DATE = '2019-05-24'; # DATE
-our $VERSION = '0.090'; # VERSION
+our $VERSION = '0.091'; # VERSION
 
 use 5.010001;
 use strict;
@@ -91,6 +91,12 @@ _
             src_plang => 'bash',
             'x.doc.max_result_lines' => 5,
         },
+        {
+            summary => 'Generate dates from yesterday to 2 weeks from now',
+            src => '[[prog]] yesterday "in 2 weeks"',
+            src_plang => 'bash',
+            'x.doc.max_result_lines' => 5,
+        },
         {
             summary => 'Generate dates from 2015-01-31 to 2015-01-01 (reverse)',
             src => '[[prog]] 2015-01-31 2015-01-01 -r',
@@ -273,7 +279,7 @@ App::dateseq - Generate a sequence of dates
 
 =head1 VERSION
 
-This document describes version 0.090 of App::dateseq (from Perl distribution App-dateseq), released on 2019-05-24.
+This document describes version 0.091 of App::dateseq (from Perl distribution App-dateseq), released on 2019-05-24.
 
 =head1 FUNCTIONS
 
